#ifndef HARKIO_HARKCONFIG_HARKCONFIGFILEREADER_HPP_
#define HARKIO_HARKCONFIG_HARKCONFIGFILEREADER_HPP_

#include <boost/shared_ptr.hpp>
#include <harkio2/AnalyzeError.hpp>

/** @file HarkConfigFileReader.hpp
 * @brief HarkConfigFileReader クラスの定義
 */

namespace harkio2
{
namespace harkconfig
{

class HarkConfigFile;

/** @brief HARK-configファイルの読み込みインターフェース。
 *
 * このインターフェースを実装した、各種ファイル形式（例えばXML形式）
 * に対応したクラスを用いることにより、様々なフォーマットのHARK-configファイルからデータを読み込むことができる。
 *
 * \sa HarkConfigFileXMLReader
 * \sa HarkConfigFileTextReader
 */
class HarkConfigFileReader
{
public:
    /// @brief 継承のための仮想デストラクタ
    virtual ~HarkConfigFileReader()
    {}

    /** @brief HARK-configファイルからデータを読み込んで返す。
     *
     * HARK-configファイルのデータをどこかから読み込み、返す。
     * 読み込む場所はサブクラスのコンストラクタやメソッドにより指定されるだろう。
     *
     * このインターフェースでは、HARK-configファイルが本当のファイルであるかどうかは規定していないため、
     * 例えば名前付きパイプなどから読み込むようなサブクラスを定義することもできる。
     * @return 読み込んだデータ
     */
    virtual boost::shared_ptr<HarkConfigFile> Read() throw (harkio2::AnalyzeError) = 0;
};

}
}

#endif // HARKIO_HARKCONFIG_HARKCONFIGFILEREADER_HPP_

